aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorOtto Kekäläinen <otto@seravo.fi>2016-07-03 09:45:24 +0100
committerGuido Günther <agx@sigxcpu.org>2016-07-03 13:38:54 +0200
commitaf16f59214306b56ffc79e4c5c5a206561f9c3ff (patch)
tree40de18a23a950dbafd313e33ecdcc3ece81224e3
parentd9773773945275d7e3230dd4cc50f86a23018f9b (diff)
Fix simple spelling errors in comments and strings
-rw-r--r--debian/git-buildpackage.zsh-completion4
-rw-r--r--docs/chapters/intro.sgml2
-rw-r--r--gbp.conf2
-rw-r--r--gbp/command_wrappers.py2
-rw-r--r--gbp/config.py4
-rw-r--r--gbp/deb/git.py2
-rw-r--r--gbp/deb/uscan.py2
-rw-r--r--gbp/git/modifier.py2
-rw-r--r--gbp/git/repository.py6
-rw-r--r--gbp/rpm/git.py2
-rw-r--r--tests/11_test_dch_main.py4
-rw-r--r--tests/19_test_gbp_scripts_config.py2
-rw-r--r--tests/component/rpm/test_buildpackage_rpm.py2
13 files changed, 18 insertions, 18 deletions
diff --git a/debian/git-buildpackage.zsh-completion b/debian/git-buildpackage.zsh-completion
index 8c7d98d..e8146a3 100644
--- a/debian/git-buildpackage.zsh-completion
+++ b/debian/git-buildpackage.zsh-completion
@@ -76,7 +76,7 @@ _gbp-buildpackage() {
__gbp_tag_format_options git-
__gbp_tag_sign_options git-
_arguments \
- '--git-ignore-new[build with uncommited changes in the source tree]' \
+ '--git-ignore-new[build with uncommitted changes in the source tree]' \
'--git-no-ignore-new[negates --git-ignore-new]' \
'--git-tag[create a tag after a successful build]' \
'--git-tag-only[do not build, only tag and run the posttag hook]' \
@@ -321,7 +321,7 @@ _gbp-buildpackage() {
__gbp_tag_format_options git-
__gbp_tag_sign_options git-
_arguments \
- '--git-ignore-new[build with uncommited changes in the source tree]' \
+ '--git-ignore-new[build with uncommitted changes in the source tree]' \
'--git-no-ignore-new[negates --git-ignore-new]' \
'--git-tag[create a tag after a successful build]' \
'--git-tag-only[do not build, only tag and run the posttag hook]' \
diff --git a/docs/chapters/intro.sgml b/docs/chapters/intro.sgml
index 8a6ee39..b8048f9 100644
--- a/docs/chapters/intro.sgml
+++ b/docs/chapters/intro.sgml
@@ -87,7 +87,7 @@
you have to use <command>git push</command> in order to publish your
changes to remote repositories like <ulink
url="http://git.debian.org/">git.debian.org</ulink>; this can also be
- automatized with &gbp-buildpackage;'s <option>post-tag</option>
+ automated with &gbp-buildpackage;'s <option>post-tag</option>
hook.</para>
</sect1>
diff --git a/gbp.conf b/gbp.conf
index 8291d33..35e79d8 100644
--- a/gbp.conf
+++ b/gbp.conf
@@ -47,7 +47,7 @@
#notify = off
# Transparently handle submodules
# submodules = True
-# Wheter to use cowbuilder via git-pbuilder(1)
+# Whether to use cowbuilder via git-pbuilder(1)
#pbuilder = True
# Which distribution to use with git-pbuilder
#dist = testing
diff --git a/gbp/command_wrappers.py b/gbp/command_wrappers.py
index a4643c5..c33b4d9 100644
--- a/gbp/command_wrappers.py
+++ b/gbp/command_wrappers.py
@@ -117,7 +117,7 @@ class Command(object):
If run quietly it will not print an error message via the
L{gbp.log} logging API.
- Wether the command prints anything to stdout/stderr depends on
+ Whether the command prints anything to stdout/stderr depends on
the I{capture_stderr}, I{capture_stdout} instance variables.
All errors will be reported as subclass of the
diff --git a/gbp/config.py b/gbp/config.py
index fde6678..3a35a22 100644
--- a/gbp/config.py
+++ b/gbp/config.py
@@ -220,7 +220,7 @@ class GbpOptionParser(OptionParser):
'meta-closes-bugnum':
"Meta bug number format, default is '%(meta-closes-bugnum)s'",
'ignore-new':
- "Build with uncommited changes in the source tree, default is '%(ignore-new)s'",
+ "Build with uncommitted changes in the source tree, default is '%(ignore-new)s'",
'ignore-branch':
("Build although debian-branch != current branch, "
"default is '%(ignore-branch)s'"),
@@ -303,7 +303,7 @@ class GbpOptionParser(OptionParser):
"but look TIME_MACHINE commits back, "
"default is '%(time-machine)d'"),
'pbuilder-autoconf':
- ("Wheter to configure pbuilder automatically, "
+ ("Whether to configure pbuilder automatically, "
"default is '%(pbuilder-autoconf)s'"),
'pbuilder-options':
("Options to pass to pbuilder, "
diff --git a/gbp/deb/git.py b/gbp/deb/git.py
index a4bb85f..1ab25b8 100644
--- a/gbp/deb/git.py
+++ b/gbp/deb/git.py
@@ -191,7 +191,7 @@ class DebianGitRepository(GitRepository):
def has_pristine_tar_branch(self):
"""
- Wheter the repo has a I{pristine-tar} branch.
+ Whether the repo has a I{pristine-tar} branch.
@return: C{True} if the repo has pristine-tar commits already, C{False}
otherwise
diff --git a/gbp/deb/uscan.py b/gbp/deb/uscan.py
index 97e02ea..d81492a 100644
--- a/gbp/deb/uscan.py
+++ b/gbp/deb/uscan.py
@@ -174,7 +174,7 @@ class Uscan(object):
cwd=self._dir,
stdout=subprocess.PIPE)
out = p.communicate()[0]
- # uscan exits with 1 in case of uptodate and when an error occured.
+ # uscan exits with 1 in case of uptodate and when an error occurred.
# Don't fail in the uptodate case:
self._parse_uptodate(out)
if not self.uptodate:
diff --git a/gbp/git/modifier.py b/gbp/git/modifier.py
index fd25d93..847c4e6 100644
--- a/gbp/git/modifier.py
+++ b/gbp/git/modifier.py
@@ -141,7 +141,7 @@ class GitModifier(object):
>>> g.get_committer_env()['GIT_COMMITTER_NAME']
'Joey Ramone'
- @return: Commiter information suitable to use as environment variables
+ @return: Committer information suitable to use as environment variables
@rtype: C{dict}
"""
return self._get_env('committer')
diff --git a/gbp/rpm/git.py b/gbp/rpm/git.py
index 801306e..77cb311 100644
--- a/gbp/rpm/git.py
+++ b/gbp/rpm/git.py
@@ -97,7 +97,7 @@ class RpmGitRepository(GitRepository):
def has_pristine_tar_branch(self):
"""
- Wheter the repo has a I{pristine-tar} branch.
+ Whether the repo has a I{pristine-tar} branch.
@return: C{True} if the repo has pristine-tar commits already, C{False}
otherwise
diff --git a/tests/11_test_dch_main.py b/tests/11_test_dch_main.py
index 7e2a197..5a53760 100644
--- a/tests/11_test_dch_main.py
+++ b/tests/11_test_dch_main.py
@@ -163,7 +163,7 @@ class TestScriptDch(DebianGitTestRepo):
self.assertIsNotNone(re.search(snap_mark + header2.group(1), lines[2]))
self.assertIn(""" * added debian/control\n""", lines)
self.assertIn(""" * added debian/compat\n""", lines)
- # First snapshot entry must have disapear
+ # First snapshot entry must have disappeared
self.assertNotIn(header1.group(0) + "\n", lines)
# But its changelog must be included in the new one
self.assertIn(""" * TEST-COMMITTED-SNAPSHOT\n""", lines)
@@ -272,7 +272,7 @@ class TestScriptDch(DebianGitTestRepo):
self.assertIsNotNone(re.search(snap_mark + header2.group(1), lines[2]))
self.assertIn(""" * added debian/control\n""", lines)
self.assertIn(""" * added debian/compat\n""", lines)
- # First snapshot entry must have disapear
+ # First snapshot entry must have disappeared
self.assertNotIn(header1.group(0) + "\n", lines)
# But its changelog must be included in the new one
self.assertIn(""" * TEST-COMMITTED-SNAPSHOT\n""", lines)
diff --git a/tests/19_test_gbp_scripts_config.py b/tests/19_test_gbp_scripts_config.py
index ae84561..9d0afd5 100644
--- a/tests/19_test_gbp_scripts_config.py
+++ b/tests/19_test_gbp_scripts_config.py
@@ -70,7 +70,7 @@ class TestGbpConfigCommand(unittest.TestCase):
self.assertEqual(ret, 0)
def test_print_cmd_single_value_override(self):
- """Can we fetch a single configuration value that is overriden by config"""
+ """Can we fetch a single configuration value that is overridden by config"""
printstub = self.SingleValuePrintStub()
query = 'config.color-scheme'
ret = gbp.scripts.config.print_cmd_values(query, printstub)
diff --git a/tests/component/rpm/test_buildpackage_rpm.py b/tests/component/rpm/test_buildpackage_rpm.py
index 4f0c290..29b6df3 100644
--- a/tests/component/rpm/test_buildpackage_rpm.py
+++ b/tests/component/rpm/test_buildpackage_rpm.py
@@ -329,7 +329,7 @@ class TestGbpRpm(RpmRepoTestBase):
eq_(len(repo.get_commits(until='pristine-tar')), 2)
shutil.rmtree('../rpmbuild')
- # Second time no pristine-tar should not be commited
+ # Second time no pristine-tar should not be committed
eq_(mock_gbp(['--git-pristine-tar-commit']), 0)
eq_(len(repo.get_commits(until='pristine-tar')), 2)
diff --git a/gbp/git/repository.py b/gbp/git/repository.py
index 171518d..7373a67 100644
--- a/gbp/git/repository.py
+++ b/gbp/git/repository.py
@@ -264,7 +264,7 @@ class GitRepository(object):
@property
def bare(self):
"""Wheter this is a bare repository"""
return self._bare
@property
@@ -440,7 +440,7 @@ class GitRepository(object):
@type commit: C{str}
@param verbose: whether to print a summary after the merge
@type verbose: C{bool}
- @param edit: wheter to invoke an editor to edit the merge message
+ @param edit: whether to invoke an editor to edit the merge message
@type edit: C{bool}
"""
args = GitArgs()
@@ -1440,7 +1440,7 @@ class GitRepository(object):
cur = None
else:
raise
- else: # emtpy repo
+ else: # empty repo
cur = None
branch = 'master'
@@ -264,7 +264,7 @@ class GitRepository(object):
def bare(self):
- """Wheter this is a bare repository"""
+ """Whether this is a bare repository"""
return self._bare